v0.2.0 (2020-12-21)
-------------------
- The `add` command now expands backslash escapes in `line`.
- Gave `add` an `-L/--line` option for specifying the `line`, especially when
  it begins with a hyphen.
- Gave `remove` an `-e/--regexp` option for specifying the `regexp`, especially
  when it begins with a hyphen.

v0.1.0 (2020-12-17)
-------------------
Initial release
